# TODO 2022-08-17

### 软件著作选题

1. 最开始选择重写 sikulix 用 python，发现不论是从前端设计，到后端实现，都有很多难点，而且达不到想要的结果。
2. 最开始选择的是 CV 的几个经典应用算法写成库打包发到网上，后来想改为去识别模型文件可以被那些深度学习框架所读取，但是需要依赖太多库。
3. 综合各种因素，暂时决定书写一个库，guto，详情在毕业设计中

### 小论文撰写

 1. 超分辨率的 REAL-ESRGAN 跑出一些结果（4倍放大），然后将结果缩小四倍，同时利用 cv2 提升锐度等，达到同分辨率下提高图片品质的结果，附上 SSIM 和 PSNR 值，算一种新算法 S，发到计算机工程与设计期刊中。

    |  时间表  | 预计可利用时间 | 需要做的事情 |
    |  ----  | ----  |  ----  |
    | 2022-08-17 到 2022-08-26 | 8.21日：3-5h<br>8.22，23，26日：1-2h<br>共 6-11h | 下载5-10篇论文，粗看一遍<br>撰写后续处理代码，将最大 SSIM 和 PSNR 值计算出<br>统计不同模型算法的平均指标值，做出比较表格<br>寻找类似低分辨率的雷达地图，做出应用接口 |
    | 2022-08-27 到 2022-09-04 | 8.27日：3-5h<br/>8.28日：2-3h<br/>8.29，30，9.2日：1-2h<br/>9.3，4日：2-3h<br/>共 12-20h | 下载期刊模板，对照先前下载的论文，开始写论文<br>争取在计划时间写完第一篇 |
    | 2022-09-05 到 2022-09-11 | 约 6-10h | 没做完的善后，投稿写好的论文，并打电话估计收稿日期 |

 2. Full-Frame 稳帧算法 FFVS ，直接用 colab 的代码跑出结果即可，不管效果怎么样，找找 metric 在哪就行，最后找出几个比对的，列出几个重要公式。
    |  时间表  | 预计可利用时间 | 需要做的事情 |
    |  ----  | ----  |  ----  |
    | 2022-09-19 到 2022-10-01 | 约 20-30h | 撰写 metric 代码，租赁服务器，跑出结果，下载5-10个论文，做出比对的表格 |
    | 2022-10-08 到 2022-10-30 | 约 30-50h | 下载期刊模板，对照先前下载的论文，开始写论文<br>争取在计划时间写完第二篇 |

### 毕业设计

1. 毕业设计共有三个重要创新点

   - 新的一个爬虫方法，这个地方书写一个库 guto，这个库利用 pyautogui + paddleocr + torch，提供几个功能

     - guto.show_frame() 生成全屏幕的网格图，分成 几成几 的块，可以直观的看到一些元素大致在什么位置

     - guto.show_position(pos=:guto.Position) 生成全屏幕的图，含有指定的位置的红色圆圈示意

     - ### 重要功能

     - guto.pos(x=:int, y=:int) -> class guto.Position 定位一个位置，将这个位置作为一个对象，可以进行各种操作

     - guto.click(pos=:guto.Position) -> bool 点击指定的位置

     - guto.doubleclick(pos=:guto.Position) -> bool 点击指定的位置

     - guto.rightclick(pos=:guto.Position) -> bool 右键点击指定的位置

     - guto.drag_to(pos_src=:guto.Position, pos_dst=:guto.Position, operate_time=:int) -> bool，从 pos_src 用 operate_time 时间，平滑的拖拽到 pos_dst

     - guto.find_pos_by_text(text=:str, frame=:()) -> guto.Position，从 frame（左上角的 pos，右下角的 pos，不填默认为全屏幕） 中寻找包含 text 的位置，返回一个 guto.Position 的 List，一行一行寻找

     - guto.screenshot(frame=:()) -> img对象，从 frame 中截图，返回 img 对象

     - guto.find_pos_by_img(img:=img对象，frame=:()) -> 从 frame 中寻找包含 img 的位置，返回位置中心点的 guto.Postion 

     - ### 还有新的功能待发掘

     - 这个库投入使用后，本身可以作为一个***软著***，结合 charles 等抓包工具可以成为一种爬虫的新方法。

   - ocr 算法的优化，在 guto.find_text 中，使用这一个新的 ocr 算法达到想要效果，（暂定先提高分辨率，再缩小分辨率，采用第一篇论文的算法），然后继续 OCR 识别，提高识别率

2. 预计从 11月初开始写，直至毕业前



​	